import * as dotenv from 'dotenv';
dotenv.config();
import * as cluster from 'cluster';
import {cpus} from 'os';
import runConsole from './components/console';
import generateServer from './core/express';
import pino from './core/pino';
import sentry from './core/sentry';
import runWorker from './core/worker';
import initScheduler from './schedule';
import executeTask from './components/tasks-executer';

const action = process.argv[2] || 'server';

switch (action) {
    case 'server':
        initScheduler();
        runServer();
        break;
    case 'console':
        runConsole();
        break;
    case 'execute':
        executeTask(process.argv[3], process.argv.slice(4));
        break;
    case 'vega':
        runVega();
        break;
    case 'worker':
        runWorker();
        break;
}

function runServer() {
    if (process.env.NODE_ENV === 'production' && cluster.isMaster) {
        const cpuCount = cpus().length;
        console.log(`Deploying ${cpuCount} http workers`);
        for (let i = 0; i < cpuCount; i += 1) {
            cluster.fork();
        }
    } else {
        const port = Number(process.env.PORT) || 4444;
        const listen = generateServer();
        listen(port);
        console.log(`Worker is listening`)
    }
}

function runVega() {
    console.log('Starting the VEGA server');
}
