import db from '../core/db';
import {log, reportError} from '../core/utils';
import {wk, SITES, WikidotUser} from '../components/wikidot-kit';

export function run(siteName: string, uid: number) {
    const wiki = SITES[siteName];
    log(`Importing member ${uid} from ${wiki.name}`);

    return wk.fetchUserProfile(wiki.url, uid)
        .then((user: WikidotUser) => {
            const memberships = {[wiki.name]: user.memberSince};
            return db.query(`
                        INSERT INTO wikidot_users AS wk_users (uid, username, about, reg_date, memberships)
                        VALUES($(uid), $(username), $(about), $(userSince), $(memberships))
                        ON CONFLICT (uid) DO UPDATE SET
                            username = $(username),
                            about = $(about),
                            memberships = wk_users.memberships || $(memberships)
                    `,
                {uid, username: user.username, about: user.about, userSince: user.userSince, memberships});
        })
        .catch(error => {
            reportError(error, {message: 'Error importing member profile', extra: {uid}});
        });
}
