import db from '../core/db';
import {log, reportError} from '../core/utils';
import {wk, SITES_LIST, WikidotXMLRPCPage, SITES} from '../components/wikidot-kit';

export function run(wikiName: string, pageName: string) {
    log(`Importing page ${wikiName}/${pageName}`);
    const wikiUrl = SITES[wikiName].url;

    return wk.fetchPage(wikiName, pageName)
        .catch((error) => {
            reportError(error, {message: 'Error importing page', extra: {wikiName, pageName}});
        })
        .then((data: WikidotXMLRPCPage) => {
            return db.query(`
                INSERT INTO wikidot_pages (
                  wiki_name,
                  name,
                  title,
                  tags,
                  rating,
                  content,
                  html,
                  created_at,
                  created_by,
                  updated_at,
                  updated_by
                )
                VALUES (
                  $(wikiName),
                  $(pageName),
                  $(title),
                  $(tags),
                  $(rating),
                  $(content),
                  $(html),
                  $(createdAt),
                  $(createdBy),
                  $(updatedAt),
                  $(updatedBy)
                )
                ON CONFLICT (name, wiki_name) DO UPDATE SET
                  title = $(title),
                  tags = $(tags)::text[],
                  rating = $(rating),
                  content = $(content),
                  html = $(html),
                  created_at = $(createdAt),
                  created_by = $(createdBy),
                  updated_at = $(updatedAt),
                  updated_by = $(updatedBy);
            `, {
                wikiName,
                pageName,
                createdAt: data.created_at,
                createdBy: data.created_by,
                updatedAt: data.updated_at,
                updatedBy: data.updated_by,
                title: data.title,
                tags: data.tags,
                rating: data.rating,
                content: data.content,
                html: data.html
            });
        })
        .then(() => {
            return wk.fetchPageVotes(wikiUrl, pageName);
        })
        .then(votes => {
            return db.query(`
                INSERT INTO wikidot_pages (wiki_name, name, votes) VALUES ($(wikiName), $(pageName), $(votes))
                ON CONFLICT (wiki_name, name) DO UPDATE SET votes = $(votes);
            `, {
                wikiName,
                pageName,
                votes: {votes}
            });
        })
        .then(() => {
            log(`[DONE] ${wikiName}/${pageName}`);
        })
        .catch((error) => {
            reportError(error, {message: 'Error saving page', extra: {wikiName, pageName}});
        });
}
